/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - 2016 S. Kyle Korndoerfer
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/** Extension that adds support for generating PlantUML diagrams */
define(function (require, exports, module) {
    "use strict";

	var _logger				=	require("lib/logging"),
		_sequenceDialect	=	require("lib/dialects/sequence"),
		_usecaseDialect		=	require("lib/dialects/usecase"),
		_classDialect		=	require("lib/dialects/class"),
		_activityDialect	=	require("lib/dialects/activity"),
		_componentDialect	=	require("lib/dialects/component"),
		_stateDialect		=	require("lib/dialects/state"),
		_objectDialect		=	require("lib/dialects/object");

	/**
	 * Registers the dialects of PlantUML
	 */
    function register() {
		_logger.debug("BEGIN: registering languages");

		_sequenceDialect.init();
		_usecaseDialect.init();
		_classDialect.init();
		_activityDialect.init();
		_componentDialect.init();
		_stateDialect.init();
		_objectDialect.init();

		_logger.debug("END: registering languages");
    };

    // Exports only the compress function
    exports.registerLanguages = register;
});
